@@ -67,7 +67,11 @@ def libdoc(app: Application, robot_options_and_args: Tuple[str, ...]) -> None:
         pass
 
     config_files, root_folder, _ = get_config_files(
-        robot_arguments, app.config.config_files, verbose_callback=app.verbose
+        robot_arguments,
+        app.config.config_files,
+        root_folder=app.config.root,
+        no_vcs=app.config.no_vcs,
+        verbose_callback=app.verbose,
     )
     try:
         profile = (
